guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

branch master updated: guix: import: Don't import yanked rust crates.


From: guix-commits
Subject: branch master updated: guix: import: Don't import yanked rust crates.
Date: Sun, 22 Oct 2023 09:57:54 -0400

This is an automated email from the git hooks/post-receive script.

efraim pushed a commit to branch master
in repository guix.

The following commit(s) were added to refs/heads/master by this push:
     new 742554f9b9 guix: import: Don't import yanked rust crates.
742554f9b9 is described below

commit 742554f9b973610a54ada9dee2971939cc36ddd7
Author: Efraim Flashner <efraim@flashner.co.il>
AuthorDate: Mon Oct 9 15:15:46 2023 +0300

    guix: import: Don't import yanked rust crates.
    
    * guix/import/crate.scm (<crate-version>): Add yanked? field.
    (crate->guix-package)[find-crate-version]: Remove versions which have
    been yanked.
    * tests/crate.scm: Adjust tests for new yanked? field.
---
 guix/import/crate.scm |  9 +++++++--
 tests/crate.scm       | 40 +++++++++++++++++++++++++++-------------
 2 files changed, 34 insertions(+), 15 deletions(-)

diff --git a/tests/crate.scm b/tests/crate.scm
index 720fcb212c..5aea5efaf3 100644
--- a/tests/crate.scm
+++ b/tests/crate.scm
@@ -3,6 +3,7 @@
 ;;; Copyright © 2016 David Craven <david@craven.ch>
 ;;; Copyright © 2019, 2020, 2022 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2020 Martin Becze <mjbecze@riseup.net>
+;;; Copyright © 2023 Efraim Flashner <efraim@flashner.co.il>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -76,21 +77,24 @@
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": \"/api/v1/crates/foo/0.8.1/dependencies\"
-        }
+        },
+        \"yanked\": false
       },
       { \"id\": 234212,
         \"num\": \"1.0.0\",
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": \"/api/v1/crates/foo/1.0.0/dependencies\"
-        }
+        },
+        \"yanked\": false
       },
       { \"id\": 234214,
         \"num\": \"1.0.3\",
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": \"/api/v1/crates/foo/1.0.3/dependencies\"
-        }
+        },
+        \"yanked\": false
       }
     ]
   }
@@ -123,14 +127,16 @@
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": \"/api/v1/crates/root/1.0.0/dependencies\"
-        }
+        },
+        \"yanked\": false
       },
       { \"id\": 234242,
         \"num\": \"1.0.4\",
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": \"/api/v1/crates/root/1.0.4/dependencies\"
-        }
+        },
+        \"yanked\": false
       }
     ]
   }
@@ -178,21 +184,24 @@
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": 
\"/api/v1/crates/intermediate-a/1.0.40/dependencies\"
-        }
+        },
+        \"yanked\": false
       },
       { \"id\": 234250,
         \"num\": \"1.0.42\",
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": 
\"/api/v1/crates/intermediate-a/1.0.42/dependencies\"
-        }
+        },
+        \"yanked\": false
       },
       { \"id\": 234252,
         \"num\": \"1.1.0-alpha.1\",
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": 
\"/api/v1/crates/intermediate-a/1.1.0-alpha.1/dependencies\"
-        }
+        },
+        \"yanked\": false
       }
     ]
   }
@@ -235,7 +244,8 @@
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": 
\"/api/v1/crates/intermediate-b/1.2.3/dependencies\"
-        }
+        },
+        \"yanked\": false
       }
     ]
   }
@@ -268,14 +278,16 @@
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": \"/api/v1/crates/leaf-alice/0.7.3/dependencies\"
-        }
+        },
+        \"yanked\": false
       },
       { \"id\": 234272,
         \"num\": \"0.7.5\",
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": \"/api/v1/crates/leaf-alice/0.7.5/dependencies\"
-        }
+        },
+        \"yanked\": false
       }
     ]
   }
@@ -302,7 +314,8 @@
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": \"/api/v1/crates/leaf-bob/3.0.1/dependencies\"
-        }
+        },
+        \"yanked\": false
       }
     ]
   }
@@ -597,7 +610,8 @@
         \"license\": \"MIT OR Apache-2.0\",
         \"links\": {
           \"dependencies\": \"/api/v1/crates/doctool/2.2.2/dependencies\"
-        }
+        },
+        \"yanked\": false
       }
     ]
   }



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/guix/import/crate.scm b/guix/import/crate.scm
index 6e10ebb5d4..43823d006e 100644
--- a/guix/import/crate.scm
+++ b/guix/import/crate.scm
@@ -5,6 +5,7 @@
 ;;; Copyright © 2021 Nicolas Goaziou <mail@nicolasgoaziou.fr>
 ;;; Copyright © 2022 Hartmut Goebel <h.goebel@crazy-compilers.com>
 ;;; Copyright © 2023 Simon Tournier <zimon.toutoune@gmail.com>
+;;; Copyright © 2023 Efraim Flashner <efraim@flashner.co.il>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -82,6 +83,7 @@
                  (match-lambda
                    ('null #f)
                    ((? string? str) str)))
+  (yanked?       crate-version-yanked? "yanked")  ;boolean
   (links         crate-version-links))            ;alist
 
 ;; Crate dependency.  Each dependency (each edge in the graph) is annotated as
@@ -255,13 +257,16 @@ look up the development dependencs for the given crate."
       (and (not (null-list? versions))
            (semver->string (last versions)))))
 
   ;; find the highest version of a crate that fulfills the semver <range>
   (define (find-crate-version crate range)
     (let* ((semver-range (string->semver-range range))
            (versions
             (sort
              (filter (lambda (entry)
-                       (semver-range-contains? semver-range (first entry)))
+                       (and
+                         (not (crate-version-yanked? (second entry)))
+                         (semver-range-contains? semver-range (first entry))))
                      (map (lambda (ver)
                             (list (string->semver (crate-version-number ver))
                                   ver))
@@ -255,13 +257,16 @@ look up the development dependencs for the given crate."
            (semver->string (last versions)))))
 
-  ;; find the highest version of a crate that fulfills the semver <range>
+  ;; Find the highest version of a crate that fulfills the semver <range>
+  ;; and hasn't been yanked.
   (define (find-crate-version crate range)
     (let* ((semver-range (string->semver-range range))